@@ -3,3 +3,6 @@ from .token import (
         DemurrageTokenSettings,
         DemurrageRedistribution,
         )
+from .token import create
+from .token import bytecode
+from .token import args
